==> jigl-1.4.0.tgz: package/README.md <==
# jQuery Input Grid Library (JIGL)

JIGL is a library of customizable form-compliant input fields and groups based on jQuery. Some features include:

- Self-validating inputs with support for email and password fields
- Support for creating a grid of inputs
- A visually appealing style with built-in labels

## Latest Version
1.4.0

## Downloading Library
This library is available using Bower and NPM. To use it in your project perform the following steps:

### Bower
```sh
$ bower install jigl
```

The main files for the library will be located in *bower_components/jigl/dist/*.

### NPM
```sh
$ npm install jigl
```

The mains files for the library will be located in *node_modules/jigl/dist/*.

There is a development version and a minified version for production.

## Contributing
First install [Node.js](https://nodejs.org/)

Next you need to install Gulp globally
```sh
$ npm install -g gulp
```

Then clone the repository and run Gulp
```sh
$ git clone https://github.com/0xKione/jquery-input-grid.git
$ cd path/to/repo
$ npm install
$ bower install
$ gulp dev
```

To generate a release build
```sh
$ cd path/to/repo
$ gulp production
```

And you're good to go!

## Usage
To learn the functionality of the library check out the [JIGL Usage](http://richardwgomez.com/index.php/jigl) page

## Status
I am still actively contributing to this repository making improvements and bug fixes. This is my first real GitHub library so there have been a few unneccesary releases, but I am getting more familiar with that process.

This library was originally designed to work with a web app I am developing called [WageKick](https://wagekick.com) and turned into a side project.

## License
MIT

==> jigl-1.4.1.tgz: package/README.md <==
# jQuery Input Grid Library (JIGL)

JIGL is a library of customizable form-compliant input fields and groups based on jQuery. Some features include:

- Self-validating inputs with support for email and password fields
- Support for creating a grid of inputs
- A visually appealing style with built-in labels

## Latest Version
1.4.1

## Downloading Library
This library is available using Bower and NPM. To use it in your project perform the following steps:

### Bower
```sh
$ bower install jigl
```

The main files for the library will be located in *bower_components/jigl/dist/*.

### NPM
```sh
$ npm install jigl
```

The mains files for the library will be located in *node_modules/jigl/dist/*.

There is a development version and a minified version for production.

## Contributing
First install [Node.js](https://nodejs.org/)

Next you need to install Gulp globally
```sh
$ npm install -g gulp
```

Then clone the repository and run Gulp
```sh
$ git clone https://github.com/0xKione/jquery-input-grid.git
$ cd path/to/repo
$ npm install
$ bower install
$ gulp dev
```

To generate a release build
```sh
$ cd path/to/repo
$ gulp production
```

And you're good to go!

## Usage
To learn the functionality of the library check out the [JIGL Usage](http://www.rwgomez.com/jigl) page

## Status
I am still actively contributing to this repository making improvements and bug fixes. This is my first real GitHub library so there have been a few unneccesary releases, but I am getting more familiar with that process.

## License
MIT
